==> msmtp-scripts-1.2.4.tar.gz: msmtp-scripts-1.2.4/tests/scripts/t00530-no-recipients.sh <==
#!/bin/sh
#
# msmtp-scripts test framework
#
#    Copyright (C) 2019 Daniel F. Dickinson <cshored@thecshore.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#!/bin/sh
#

OTS=SUCCESS

rm -rf ./tmp/msmtp.queue/*
rm -f ./tmp/msmtp.queue.log

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-no-recip.rc

TS=PASS

echo "Subject: test no recipients
       
Test no recipients" | /usr/bin/msmtpq-ng root
MCTRC=$?

if [ "$MCTRC" != "67" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: msmtp returning no recipients fails"

TS=PASS

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-no-recip-ignore.rc

TS=PASS

echo "Subject: test no recipients
       
Test no recipients" | /usr/bin/msmtpq-ng root
MCTRC=$?

if [ "$MCTRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Sending a message with no recipients but ignoring, succeeds"

/usr/bin/msmtpq-ng -qI ALL
MCTRC=$?

if [ "$MCTRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: running queue msg no recipients, but ignoring, succeeds"

if [ "$OTS" = "FAIL" ]; then
	exit 3
else
	exit 0
fi

==> msmtp-scripts-1.2.5.1.tar.gz: msmtp-scripts-1.2.5.1/tests/scripts/t00530-no-recipients.sh <==
#!/bin/sh
#
# msmtp-scripts test framework
#
#    Copyright (C) 2019 Daniel F. Dickinson <cshored@thecshore.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#!/bin/sh
#

OTS=SUCCESS

rm -rf ./tmp/msmtp.queue/*
rm -f ./tmp/msmtp.queue.log

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-no-recip.rc

TS=PASS

echo "Subject: test no recipients

Test no recipients" | MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}3-1  /usr/bin/msmtpq-ng -kcov "${KCOV_BASE}3-1" root
MCTRC=$?

if [ "$MCTRC" != "67" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: msmtp returning no recipients fails"

rm -rf ./tmp/msmtp.queue/*
rm -f ./tmp/msmtp.queue.log

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-no-recip-ignore.rc

TS=PASS

echo "Subject: test no recipients

Test no recipients" | MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}3-2 /usr/bin/msmtpq-ng -kcov "${KCOV_BASE}3-2" root
MCTRC=$?

if [ "$MCTRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Sending a message with no recipients but ignoring, succeeds"

rm -rf ./tmp/msmtp.queue/*
rm -f ./tmp/msmtp.queue.log

 MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}3-3 /usr/bin/msmtpq-ng -kcov "${KCOV_BASE}3-3" -qI ALL
MCTRC=$?

if [ "$MCTRC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: running queue msg no recipients, but ignoring, succeeds"

rm -rf ./tmp/msmtp.queue/*
rm -f ./tmp/msmtp.queue.log

if [ "$OTS" = "FAIL" ]; then
	exit 3
else
	exit 0
fi
